package com.temboo.Library.NYTimes.BestSellers;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
GetBestSellerHistory

Retrieves information about New York Times best-sellers that match a specified search criteria.
*/
public class GetBestSellerHistory extends Choreography {

	/**
	Create a new instance of the GetBestSellerHistory Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public GetBestSellerHistory(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/NYTimes/BestSellers/GetBestSellerHistory"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return GetBestSellerHistoryInputSet
	*/
	public GetBestSellerHistoryInputSet newInputSet() {
		return new GetBestSellerHistoryInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public GetBestSellerHistoryResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new GetBestSellerHistoryResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the GetBestSellerHistory
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class GetBestSellerHistoryInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by NY Times.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}


		/** 
		Set the value of the AgeGroup input for this Choreo. 

		@param String - (optional, string) The target age group for the best seller.
		*/
		public void set_AgeGroup(String value) {
			this.setInput("AgeGroup", value);
		}


		/** 
		Set the value of the Author input for this Choreo. 

		@param String - (optional, string) The author of the best seller.
		*/
		public void set_Author(String value) {
			this.setInput("Author", value);
		}


		/** 
		Set the value of the Contributor input for this Choreo. 

		@param String - (optional, string) The author of the best seller, as well as other contributors such as the illustrator.
		*/
		public void set_Contributor(String value) {
			this.setInput("Contributor", value);
		}


		/** 
		Set the value of the ISBN input for this Choreo. 

		@param String - (optional, string) International Standard Book Number, 10 or 13 digits.
		*/
		public void set_ISBN(String value) {
			this.setInput("ISBN", value);
		}


		/** 
		Set the value of the Offset input for this Choreo. 

		@param Integer - (optional, integer) The first 20 results are shown by default. To page through the results, set Offset to the appropriate value.
		*/
		public void set_Offset(Integer value) {
			this.setInput("Offset", value);
		}

		/** 
		Set the value of the Offset input for this Choreo as a String. 

		@param String - (optional, integer) The first 20 results are shown by default. To page through the results, set Offset to the appropriate value.
		*/
		public void set_Offset(String value) {
			this.setInput("Offset", value);	
		}
		/** 
		Set the value of the Price input for this Choreo. 

		@param BigDecimal - (optional, decimal) The publisher's list price of the best seller, including decimal point.
		*/
		public void set_Price(BigDecimal value) {
			this.setInput("Price", value);
		}

		/** 
		Set the value of the Price input for this Choreo as a String. 

		@param String - (optional, decimal) The publisher's list price of the best seller, including decimal point.
		*/
		public void set_Price(String value) {
			this.setInput("Price", value);	
		}
		/** 
		Set the value of the Publisher input for this Choreo. 

		@param String - (optional, string) The standardized name of the publisher.
		*/
		public void set_Publisher(String value) {
			this.setInput("Publisher", value);
		}


		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that the response should bein. Valid values are: json (the default), and xml.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}


		/** 
		Set the value of the SortBy input for this Choreo. 

		@param String - (optional, string) The column name to sort by. Valid values are: age-group, author, contributor, isbn, price, publisher, and title.
		*/
		public void set_SortBy(String value) {
			this.setInput("SortBy", value);
		}


		/** 
		Set the value of the SortOrder input for this Choreo. 

		@param String - (optional, string) The sort order. Valid values are: ASC and DESC.
		*/
		public void set_SortOrder(String value) {
			this.setInput("SortOrder", value);
		}


		/** 
		Set the value of the Title input for this Choreo. 

		@param String - (conditional, string) The title of the best seller to retrieve data for.
		*/
		public void set_Title(String value) {
			this.setInput("Title", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the GetBestSellerHistory Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class GetBestSellerHistoryResultSet extends ResultSet {
		public GetBestSellerHistoryResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from the NY Times API.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
