package com.temboo.Library.Utilities.Email;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
SendEmail

Sends an email using a specified email server.
*/
public class SendEmail extends Choreography {

	/**
	Create a new instance of the SendEmail Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public SendEmail(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Utilities/Email/SendEmail"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return SendEmailInputSet
	*/
	public SendEmailInputSet newInputSet() {
		return new SendEmailInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public SendEmailResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new SendEmailResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the SendEmail
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class SendEmailInputSet extends InputSet {
		/** 
		Set the value of the Attachment input for this Choreo. 

		@param String - (optional, string) The Base64 encoded contents of the file to attach to the email.  Use this instead of AttachmentURL.
		*/
		public void set_Attachment(String value) {
			this.setInput("Attachment", value);
		}


		/** 
		Set the value of the AttachmentName input for this Choreo. 

		@param String - (optional, string) The name of the file to attach to the email.
		*/
		public void set_AttachmentName(String value) {
			this.setInput("AttachmentName", value);
		}


		/** 
		Set the value of the AttachmentURL input for this Choreo. 

		@param String - (optional, string) URL of a hosted file that you wish to add as an attachment.  Use this instead of a normal Attachment.
		*/
		public void set_AttachmentURL(String value) {
			this.setInput("AttachmentURL", value);
		}


		/** 
		Set the value of the BCC input for this Choreo. 

		@param String - (optional, string) An email address to BCC on the email you're sending. Can be a comma separated list of email addresses.
		*/
		public void set_BCC(String value) {
			this.setInput("BCC", value);
		}


		/** 
		Set the value of the CC input for this Choreo. 

		@param String - (optional, string) An email address to CC on the email you're sending. Can be a comma separated list of email addresses.
		*/
		public void set_CC(String value) {
			this.setInput("CC", value);
		}


		/** 
		Set the value of the FromAddress input for this Choreo. 

		@param String - (conditional, string) The name and email address that the message is being sent from.
		*/
		public void set_FromAddress(String value) {
			this.setInput("FromAddress", value);
		}


		/** 
		Set the value of the MessageBody input for this Choreo. 

		@param String - (required, string) The message body for the email.
		*/
		public void set_MessageBody(String value) {
			this.setInput("MessageBody", value);
		}


		/** 
		Set the value of the Password input for this Choreo. 

		@param String - (required, password) The password for your email account.
		*/
		public void set_Password(String value) {
			this.setInput("Password", value);
		}


		/** 
		Set the value of the Port input for this Choreo. 

		@param Integer - (required, integer) Specify the port number (i.e. 25 or 465).
		*/
		public void set_Port(Integer value) {
			this.setInput("Port", value);
		}

		/** 
		Set the value of the Port input for this Choreo as a String. 

		@param String - (required, integer) Specify the port number (i.e. 25 or 465).
		*/
		public void set_Port(String value) {
			this.setInput("Port", value);	
		}
		/** 
		Set the value of the Server input for this Choreo. 

		@param String - (required, string) The name or IP address of the email server.
		*/
		public void set_Server(String value) {
			this.setInput("Server", value);
		}


		/** 
		Set the value of the Subject input for this Choreo. 

		@param String - (required, string) The subject line of the email.
		*/
		public void set_Subject(String value) {
			this.setInput("Subject", value);
		}


		/** 
		Set the value of the ToAddress input for this Choreo. 

		@param String - (required, string) The email address that you want to send an email to. Can be a comma separated list of email addresses.
		*/
		public void set_ToAddress(String value) {
			this.setInput("ToAddress", value);
		}


		/** 
		Set the value of the UseSSL input for this Choreo. 

		@param Boolean - (optional, boolean) Set to 1 to connect over SSL. Set to 0 for no SSL. Defaults to 1.
		*/
		public void set_UseSSL(Boolean value) {
			this.setInput("UseSSL", value);
		}

		/** 
		Set the value of the UseSSL input for this Choreo as a String. 

		@param String - (optional, boolean) Set to 1 to connect over SSL. Set to 0 for no SSL. Defaults to 1.
		*/
		public void set_UseSSL(String value) {
			this.setInput("UseSSL", value);	
		}
		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) Your username for your email account.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the SendEmail Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class SendEmailResultSet extends ResultSet {
		public SendEmailResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Success" output from this Choreo execution

		@return String - (boolean) Indicates the result of the SMTP operation. The value will be "true" for a successful request.
		*/
		public String get_Success() {
			return this.getResultString("Success");
		}
	}
	
}
